Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(331)

Unified Diff: remoting/host/screen_recorder_unittest.cc

Issue 10696134: remoting/host: Rename Capturer to VideoFrameCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/screen_recorder_unittest.cc
diff --git a/remoting/host/screen_recorder_unittest.cc b/remoting/host/screen_recorder_unittest.cc
index a99adf39fc5404a3af4715c61596136e462eba00..a33bb39cccc09ec4fe4518523101bad4c7d3a534 100644
--- a/remoting/host/screen_recorder_unittest.cc
+++ b/remoting/host/screen_recorder_unittest.cc
@@ -73,7 +73,7 @@ class ScreenRecorderTest : public testing::Test {
}
virtual void SetUp() OVERRIDE {
// Capturer and Encoder are owned by ScreenRecorder.
encoder_ = new MockEncoder();
session_ = new MockSession();
@@ -108,7 +108,7 @@ class ScreenRecorderTest : public testing::Test {
scoped_ptr<MockConnectionToClient> connection_;
// The following mock objects are owned by ScreenRecorder.
- MockCapturer capturer_;
+ MockVideoFrameCapturer capturer_;
MockEncoder* encoder_;
private:
@@ -73,7 +73,7 @@ class ScreenRecorderTest : public testing::Test {
}
virtual void SetUp() OVERRIDE {
- // Capturer and Encoder are owned by ScreenRecorder.
+ // VideoFrameCapturer and Encoder are owned by ScreenRecorder.
encoder_ = new MockEncoder();
session_ = new MockSession();

Powered by Google App Engine
This is Rietveld 408576698